@@ -1,7 +1,6 @@
 import unittest
 
 from pycrosskit.envariables import SysEnv
-from pycrosskit.shortcuts import Shortcut
 
 
 class TestEnvVars(unittest.TestCase):
@@ -13,21 +12,18 @@ class TestEnvVars(unittest.TestCase):
             self.fail("")
 
     def test_get_var(self):
+        SysEnv.set_var("test", "test")
         self.assertEqual(SysEnv.get_var("test"), "test")
 
     def test_get_rm_var(self):
+        SysEnv.set_var("test", "test")
         self.assertEqual(SysEnv.get_var("test", delete=True), "test")
         try:
             SysEnv.get_var("test")
             self.fail()
-        except FileNotFoundError:
+        except Exception:
             pass
 
-    def test_get_var_sub_key(self):
-        if Shortcut.get_platform() == "win":
-            SysEnv.set_var("test", "test", subkey="test")
-            self.assertEqual(SysEnv.get_var("test", sub_key="test"), "test")
-
 
 if __name__ == '__main__':
     unittest.main()
